@@ -206,7 +206,7 @@ class Stack(collections.abc.Mapping):
 
         # This will use the provided tenant ID when loading the stack
         # from the DB or get it from the context for new stacks.
-        self.tenant_id = tenant_id or self.context.tenant_id
+        self.tenant_id = tenant_id or self.context.project_id
         self.username = username or self.context.username
 
         resources.initialise()
@@ -553,7 +553,7 @@ class Stack(collections.abc.Mapping):
             stored_context = common_context.StoredContext.from_dict(creds)
 
             if cfg.CONF.deferred_auth_method == 'trusts':
-                old_trustor_proj_id = stored_context.tenant_id
+                old_trustor_proj_id = stored_context.project_id
                 old_trustor_user_id = stored_context.trustor_user_id
 
                 trustor_user_id = context.auth_plugin.get_user_id(
@@ -1343,7 +1343,7 @@ class Stack(collections.abc.Mapping):
         elif create_if_missing:
             kwargs = self.get_kwargs_for_cloning(keep_tags=True)
             kwargs['owner_id'] = self.id
-            del(kwargs['prev_raw_template_id'])
+            del kwargs['prev_raw_template_id']
             prev = type(self)(self.context, self._backup_name(),
                               copy.deepcopy(self.t),
                               **kwargs)
@@ -1889,11 +1889,13 @@ class Stack(collections.abc.Mapping):
     def _try_get_user_creds(self):
         # There are cases where the user_creds cannot be returned
         # due to credentials truncated when being saved to DB.
-        # Ignore this error instead of blocking stack deletion.
+        # Also, there are cases where auth_encryption_key has
+        # changed for some reason.
+        # Ignore these errors instead of blocking stack deletion.
         try:
             return ucreds_object.UserCreds.get_by_id(self.context,
                                                      self.user_creds_id)
-        except exception.Error:
+        except (exception.Error, exception.InvalidEncryptionKey):
             LOG.exception("Failed to retrieve user_creds")
             return None
 
@@ -2130,7 +2132,8 @@ class Stack(collections.abc.Mapping):
 
     def delete_all_snapshots(self):
         """Remove all snapshots for this stack."""
-        snapshots = snapshot_object.Snapshot.get_all(self.context, self.id)
+        snapshots = snapshot_object.Snapshot.get_all_by_stack(
+            self.context, self.id)
         for snapshot in snapshots:
             self.delete_snapshot(snapshot)
             snapshot_object.Snapshot.delete(self.context, snapshot.id)
