@@ -17,6 +17,7 @@ from unittest import mock
 
 import eventlet
 
+from heat.common import exception
 from heat.common import timeutils
 from heat.engine import dependencies
 from heat.engine import scheduler
@@ -259,7 +260,7 @@ class DependencyTaskGroupTest(common.HeatTestCase):
         d = dependencies.Dependencies([('first', 'second'),
                                        ('second', 'third'),
                                        ('third', 'first')])
-        self.assertRaises(dependencies.CircularDependencyException,
+        self.assertRaises(exception.CircularDependencyException,
                           scheduler.DependencyTaskGroup, d)
 
     def test_aggregate_exceptions_raises_all_at_the_end(self):
@@ -1273,10 +1274,10 @@ class DescriptionTest(common.HeatTestCase):
     def test_unicode(self):
         class C(object):
             def __str__(self):
-                return u'C "\u2665"'
+                return 'C "\u2665"'
 
             def __repr__(self):
-                return u'\u2665'
+                return '\u2665'
 
             def __call__(self):
                 pass
@@ -1284,423 +1285,7 @@ class DescriptionTest(common.HeatTestCase):
             def m(self):
                 pass
 
-        self.assertEqual(u'm from C "\u2665"',
+        self.assertEqual('m from C "\u2665"',
                          scheduler.task_description(C().m))
-        self.assertEqual(u'\u2665',
+        self.assertEqual('\u2665',
                          scheduler.task_description(C()))
-
-
-class WrapperTaskTest(common.HeatTestCase):
-
-    def setUp(self):
-        super(WrapperTaskTest, self).setUp()
-
-    def test_wrap(self):
-        child_tasks = [DummyTask() for i in range(3)]
-
-        @scheduler.wrappertask
-        def task():
-            for child_task in child_tasks:
-                yield child_task()
-
-            yield
-
-        for child_task in child_tasks:
-            child_task.do_step = mock.Mock(return_value=None)
-        self.patchobject(scheduler.TaskRunner, '_sleep', return_value=None)
-
-        scheduler.TaskRunner(task)()
-
-        for child_task in child_tasks:
-            child_task.do_step.assert_has_calls([mock.call(1), mock.call(2),
-                                                 mock.call(3)])
-            self.assertEqual(3, child_task.do_step.call_count)
-        scheduler.TaskRunner._sleep.assert_any_call(0)
-        scheduler.TaskRunner._sleep.assert_called_with(1)
-        self.assertEqual(1 + len(child_tasks) * 3,
-                         scheduler.TaskRunner._sleep.call_count)
-
-    def test_parent_yield_value(self):
-        @scheduler.wrappertask
-        def parent_task():
-            yield
-            yield 3
-            yield iter([1, 2, 4])
-
-        task = parent_task()
-
-        self.assertIsNone(next(task))
-        self.assertEqual(3, next(task))
-        self.assertEqual([1, 2, 4], list(next(task)))
-
-    def test_child_yield_value(self):
-        def child_task():
-            yield
-            yield 3
-            yield iter([1, 2, 4])
-
-        @scheduler.wrappertask
-        def parent_task():
-            yield child_task()
-
-        task = parent_task()
-
-        self.assertIsNone(next(task))
-        self.assertEqual(3, next(task))
-        self.assertEqual([1, 2, 4], list(next(task)))
-
-    def test_child_exception(self):
-        class MyException(Exception):
-            pass
-
-        def child_task():
-            yield
-
-            raise MyException()
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except MyException:
-                raise
-            else:
-                self.fail('No exception raised in parent_task')
-
-        task = parent_task()
-        next(task)
-        self.assertRaises(MyException, next, task)
-
-    def test_child_exception_exit(self):
-        class MyException(Exception):
-            pass
-
-        def child_task():
-            yield
-
-            raise MyException()
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except MyException:
-                return
-            else:
-                self.fail('No exception raised in parent_task')
-
-        task = parent_task()
-        next(task)
-        self.assertRaises(StopIteration, next, task)
-
-    def test_child_exception_swallow(self):
-        class MyException(Exception):
-            pass
-
-        def child_task():
-            yield
-
-            raise MyException()
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except MyException:
-                yield
-            else:
-                self.fail('No exception raised in parent_task')
-
-            yield
-
-        task = parent_task()
-        next(task)
-        next(task)
-
-    def test_child_exception_swallow_next(self):
-        class MyException(Exception):
-            pass
-
-        def child_task():
-            yield
-
-            raise MyException()
-
-        dummy = DummyTask()
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except MyException:
-                pass
-            else:
-                self.fail('No exception raised in parent_task')
-
-            yield dummy()
-
-        task = parent_task()
-        next(task)
-
-        dummy.do_step = mock.Mock(return_value=None)
-        for i in range(1, dummy.num_steps + 1):
-            next(task)
-        self.assertRaises(StopIteration, next, task)
-
-        dummy.do_step.assert_has_calls([mock.call(i)
-                                        for i in range(1,
-                                                       dummy.num_steps + 1)])
-        self.assertEqual(dummy.num_steps, dummy.do_step.call_count)
-
-    def test_thrown_exception_swallow_next(self):
-        class MyException(Exception):
-            pass
-
-        dummy = DummyTask()
-
-        @scheduler.wrappertask
-        def child_task():
-            try:
-                yield
-            except MyException:
-                yield dummy()
-            else:
-                self.fail('No exception raised in child_task')
-
-        @scheduler.wrappertask
-        def parent_task():
-            yield child_task()
-
-        task = parent_task()
-
-        dummy.do_step = mock.Mock(return_value=None)
-
-        next(task)
-        task.throw(MyException)
-
-        for i in range(2, dummy.num_steps + 1):
-            next(task)
-        self.assertRaises(StopIteration, next, task)
-
-        dummy.do_step.assert_has_calls([mock.call(i)
-                                        for i in range(1,
-                                                       dummy.num_steps + 1)])
-        self.assertEqual(dummy.num_steps, dummy.do_step.call_count)
-
-    def test_thrown_exception_raise(self):
-        class MyException(Exception):
-            pass
-
-        dummy = DummyTask()
-
-        @scheduler.wrappertask
-        def child_task():
-            try:
-                yield
-            except MyException:
-                raise
-            else:
-                self.fail('No exception raised in child_task')
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except MyException:
-                yield dummy()
-
-        task = parent_task()
-
-        dummy.do_step = mock.Mock(return_value=None)
-
-        next(task)
-        task.throw(MyException)
-
-        for i in range(2, dummy.num_steps + 1):
-            next(task)
-        self.assertRaises(StopIteration, next, task)
-
-        dummy.do_step.assert_has_calls([mock.call(i)
-                                        for i in range(1,
-                                                       dummy.num_steps + 1)])
-        self.assertEqual(dummy.num_steps, dummy.do_step.call_count)
-
-    def test_thrown_exception_exit(self):
-        class MyException(Exception):
-            pass
-
-        dummy = DummyTask()
-
-        @scheduler.wrappertask
-        def child_task():
-            try:
-                yield
-            except MyException:
-                return
-            else:
-                self.fail('No exception raised in child_task')
-
-        @scheduler.wrappertask
-        def parent_task():
-            yield child_task()
-            yield dummy()
-
-        task = parent_task()
-
-        dummy.do_step = mock.Mock(return_value=None)
-
-        next(task)
-        task.throw(MyException)
-
-        for i in range(2, dummy.num_steps + 1):
-            next(task)
-        self.assertRaises(StopIteration, next, task)
-
-        dummy.do_step.assert_has_calls([mock.call(i)
-                                        for i in range(1,
-                                                       dummy.num_steps + 1)])
-        self.assertEqual(dummy.num_steps, dummy.do_step.call_count)
-
-    def test_parent_exception(self):
-        class MyException(Exception):
-            pass
-
-        def child_task():
-            yield
-
-        @scheduler.wrappertask
-        def parent_task():
-            yield child_task()
-            raise MyException()
-
-        task = parent_task()
-        next(task)
-        self.assertRaises(MyException, next, task)
-
-    def test_parent_throw(self):
-        class MyException(Exception):
-            pass
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield DummyTask()()
-            except MyException:
-                raise
-            else:
-                self.fail('No exception raised in parent_task')
-
-        task = parent_task()
-        next(task)
-        self.assertRaises(MyException, task.throw, MyException())
-
-    def test_parent_throw_exit(self):
-        class MyException(Exception):
-            pass
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield DummyTask()()
-            except MyException:
-                return
-            else:
-                self.fail('No exception raised in parent_task')
-
-        task = parent_task()
-        next(task)
-        self.assertRaises(StopIteration, task.throw, MyException())
-
-    def test_parent_cancel(self):
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield
-            except GeneratorExit:
-                raise
-            else:
-                self.fail('parent_task not closed')
-
-        task = parent_task()
-        next(task)
-        task.close()
-
-    def test_parent_cancel_exit(self):
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield
-            except GeneratorExit:
-                return
-            else:
-                self.fail('parent_task not closed')
-
-        task = parent_task()
-        next(task)
-        task.close()
-
-    def test_cancel(self):
-        def child_task():
-            try:
-                yield
-            except GeneratorExit:
-                raise
-            else:
-                self.fail('child_task not closed')
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except GeneratorExit:
-                raise
-            else:
-                self.fail('parent_task not closed')
-
-        task = parent_task()
-        next(task)
-        task.close()
-
-    def test_cancel_exit(self):
-        def child_task():
-            try:
-                yield
-            except GeneratorExit:
-                return
-            else:
-                self.fail('child_task not closed')
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except GeneratorExit:
-                raise
-            else:
-                self.fail('parent_task not closed')
-
-        task = parent_task()
-        next(task)
-        task.close()
-
-    def test_cancel_parent_exit(self):
-        def child_task():
-            try:
-                yield
-            except GeneratorExit:
-                return
-            else:
-                self.fail('child_task not closed')
-
-        @scheduler.wrappertask
-        def parent_task():
-            try:
-                yield child_task()
-            except GeneratorExit:
-                return
-            else:
-                self.fail('parent_task not closed')
-
-        task = parent_task()
-        next(task)
-        task.close()
