@@ -93,9 +93,13 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         self.t = template_format.parse(cinder_volume_template)
         self.use_cinder = True
 
-    def create_volume(self, t, stack, resource_name):
-        return super(CinderVolumeTest, self).create_volume(
+    def create_volume(self, t, stack, resource_name,
+                      mock_check_extend_ready=True):
+        rsrc = super(CinderVolumeTest, self).create_volume(
             t, stack, resource_name, validate=False)
+        if mock_check_extend_ready:
+            rsrc._ready_to_extend_volume = mock.Mock(return_value=True)
+        return rsrc
 
     def _mock_create_volume(self, fv, stack_name, size=1,
                             final_status='available', extra_get_mocks=[],
@@ -250,23 +254,23 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         stack = utils.parse_stack(self.t, stack_name=self.stack_name)
         rsrc = self.create_volume(self.t, stack, 'volume')
 
-        self.assertEqual(u'zone1', rsrc.FnGetAtt('availability_zone'))
-        self.assertEqual(u'1', rsrc.FnGetAtt('size'))
-        self.assertEqual(u'snap-123', rsrc.FnGetAtt('snapshot_id'))
-        self.assertEqual(u'name', rsrc.FnGetAtt('display_name'))
-        self.assertEqual(u'desc', rsrc.FnGetAtt('display_description'))
-        self.assertEqual(u'lvm', rsrc.FnGetAtt('volume_type'))
+        self.assertEqual('zone1', rsrc.FnGetAtt('availability_zone'))
+        self.assertEqual('1', rsrc.FnGetAtt('size'))
+        self.assertEqual('snap-123', rsrc.FnGetAtt('snapshot_id'))
+        self.assertEqual('name', rsrc.FnGetAtt('display_name'))
+        self.assertEqual('desc', rsrc.FnGetAtt('display_description'))
+        self.assertEqual('lvm', rsrc.FnGetAtt('volume_type'))
         self.assertEqual(json.dumps({'key': 'value'}),
                          rsrc.FnGetAtt('metadata'))
         self.assertEqual({'key': 'value'},
                          rsrc.FnGetAtt('metadata_values'))
-        self.assertEqual(u'None', rsrc.FnGetAtt('source_volid'))
-        self.assertEqual(u'available', rsrc.FnGetAtt('status'))
-        self.assertEqual(u'2013-02-25T02:40:21.000000',
+        self.assertEqual('None', rsrc.FnGetAtt('source_volid'))
+        self.assertEqual('available', rsrc.FnGetAtt('status'))
+        self.assertEqual('2013-02-25T02:40:21.000000',
                          rsrc.FnGetAtt('created_at'))
-        self.assertEqual(u'False', rsrc.FnGetAtt('bootable'))
-        self.assertEqual(u'False', rsrc.FnGetAtt('encrypted'))
-        self.assertEqual(u'[]', rsrc.FnGetAtt('attachments'))
+        self.assertEqual('False', rsrc.FnGetAtt('bootable'))
+        self.assertEqual('False', rsrc.FnGetAtt('encrypted'))
+        self.assertEqual('[]', rsrc.FnGetAtt('attachments'))
         self.assertEqual([], rsrc.FnGetAtt('attachments_list'))
         error = self.assertRaises(exception.InvalidTemplateAttribute,
                                   rsrc.FnGetAtt, 'unknown')
@@ -302,7 +306,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         scheduler.TaskRunner(rsrc.delete)()
 
         self.fc.volumes.get_server_volume.assert_called_with(
-            u'WikiDatabase', 'vol-123')
+            'WikiDatabase', 'vol-123')
         self.fc.volumes.delete_server_volume.assert_called_with(
             'WikiDatabase', 'vol-123')
 
@@ -333,7 +337,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         scheduler.TaskRunner(rsrc.delete)()
 
         self.fc.volumes.get_server_volume.assert_called_with(
-            u'WikiDatabase', 'vol-123')
+            'WikiDatabase', 'vol-123')
         self.fc.volumes.delete_server_volume.assert_called_with(
             'WikiDatabase', 'vol-123')
 
@@ -445,6 +449,36 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         self.stack_name = 'test_cvolume_extend_att_stack'
         self._update_if_attached(self.stack_name)
 
+    def test_cinder_volume_extend_attached_live(self):
+        self.patchobject(cinder.CinderClientPlugin, 'get_max_microversion',
+                         return_value='3.42')
+        self.stack_name = 'test_cvolume_extend_live_att_stack'
+
+        fv = vt_base.FakeVolume('available',
+                                size=1, attachments=[])
+        self._mock_create_volume(vt_base.FakeVolume('creating'),
+                                 self.stack_name,
+                                 extra_get_mocks=[
+                                     fv, vt_base.FakeVolume('extending'),
+                                     vt_base.FakeVolume('extending'),
+                                     vt_base.FakeVolume('in-use')])
+
+        stack = utils.parse_stack(self.t, stack_name=self.stack_name)
+
+        rsrc = self.create_volume(self.t, stack, 'volume')
+
+        props = copy.deepcopy(rsrc.properties.data)
+        props['size'] = 2
+        after = rsrc_defn.ResourceDefinition(rsrc.name, rsrc.type(), props)
+
+        update_task = scheduler.TaskRunner(rsrc.update, after)
+        self.assertIsNone(update_task())
+
+        self.assertEqual((rsrc.UPDATE, rsrc.COMPLETE), rsrc.state)
+        self.cinder_fc.volumes.extend.assert_called_once_with(fv.id, 2)
+        self.fc.volumes.get_server_volume.assert_not_called()
+        self.fc.volumes.delete_server_volume.assert_not_called()
+
     def test_cinder_volume_extend_created_from_backup_with_same_size(self):
         self.stack_name = 'test_cvolume_extend_snapsht_stack'
 
@@ -571,7 +605,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
             size=1, availability_zone='nova',
             description='test_description',
             name='test_name',
-            metadata={u'key': u'value'})
+            metadata={'key': 'value'})
         self.cinder_fc.volumes.get.assert_called_with(fv.id)
 
     def test_cinder_volume_update_no_need_replace(self):
@@ -625,7 +659,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
             extra_create_server_volume_mocks=[fv3])
         attachments = [{'id': 'vol-123',
                         'device': '/dev/vdc',
-                        'server_id': u'WikiDatabase'}]
+                        'server_id': 'WikiDatabase'}]
         fv2 = vt_base.FakeVolume('in-use',
                                  attachments=attachments, size=1)
         fvd = vt_base.FakeVolume('in-use')
@@ -674,7 +708,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         if update_type == 'resize':
             self.cinder_fc.volumes.extend.assert_called_once_with(fvd.id, 2)
         self.fc.volumes.get_server_volume.assert_called_with(
-            u'WikiDatabase', 'vol-123')
+            'WikiDatabase', 'vol-123')
         self.fc.volumes.delete_server_volume.assert_called_with(
             'WikiDatabase', 'vol-123')
 
@@ -748,7 +782,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         self.assertEqual((rsrc.SNAPSHOT, rsrc.FAILED), rsrc.state)
         self.assertIn(fail_reason, rsrc.status_reason)
 
-        self.assertEqual({u'backup_id': u'backup-123'},
+        self.assertEqual({'backup_id': 'backup-123'},
                          resource_data_object.ResourceData.get_all(rsrc))
         self.cinder_fc.volumes.create.assert_called_once_with(
             size=1, availability_zone=None,
@@ -796,7 +830,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
 
         self.assertEqual((rsrc.UPDATE, rsrc.COMPLETE), rsrc.state)
         self.fc.volumes.get_server_volume.assert_called_with(
-            u'WikiDatabase', 'vol-123')
+            'WikiDatabase', 'vol-123')
         self.fc.volumes.delete_server_volume.assert_called_with(
             'WikiDatabase', 'vol-123')
 
@@ -850,7 +884,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
             metadata={}
         )
         self.fc.volumes.get_server_volume.assert_called_with(
-            u'WikiDatabase', 'vol-123')
+            'WikiDatabase', 'vol-123')
         self.fc.volumes.delete_server_volume.assert_called_with(
             'WikiDatabase', 'vol-123')
 
@@ -889,7 +923,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
 
         self.assertEqual((rsrc.UPDATE, rsrc.COMPLETE), rsrc.state)
         self.fc.volumes.get_server_volume.assert_called_with(
-            u'WikiDatabase', 'vol-123')
+            'WikiDatabase', 'vol-123')
         self.fc.volumes.delete_server_volume.assert_called_with(
             'WikiDatabase', 'vol-123')
 
@@ -1252,7 +1286,7 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
         vol.to_dict.return_value = vol_resp
         rsrc.client().volumes = mock.MagicMock()
         rsrc.client().volumes.get = mock.MagicMock(return_value=vol)
-        rsrc.client().volume_api_version = 2
+        rsrc.client().volume_api_version = 3
         rsrc.data = mock.MagicMock(return_value={'volume_type': 'lvmdriver-1'})
 
         reality = rsrc.get_live_state(rsrc.properties)
@@ -1375,3 +1409,60 @@ class CinderVolumeTest(vt_base.VolumeTestCase):
             name=vol_name,
             metadata={}
         )
+
+    def test_ready_to_extend_volume(self):
+        self.stack_name = 'test_ready_to_extend_volume'
+
+        self._mock_create_volume(vt_base.FakeVolume('creating'),
+                                 self.stack_name,
+                                 extra_get_mocks=[
+                                     vt_base.FakeVolume('extending'),
+                                     vt_base.FakeVolume('reserved'),
+                                     vt_base.FakeVolume('in-use'),
+                                     vt_base.FakeVolume('available'),
+                                     vt_base.FakeVolume('creating'),
+                                     vt_base.FakeVolume('extending'),
+                                     vt_base.FakeVolume('reserved'),
+                                     vt_base.FakeVolume('in-use'),
+                                     vt_base.FakeVolume('available')])
+
+        stack = utils.parse_stack(self.t, stack_name=self.stack_name)
+
+        rsrc = self.create_volume(self.t, stack, 'volume',
+                                  mock_check_extend_ready=False)
+
+        self.assertEqual(False, rsrc._ready_to_extend_volume())
+        self.assertEqual(False, rsrc._ready_to_extend_volume())
+        self.assertEqual(False, rsrc._ready_to_extend_volume())
+        self.assertEqual(True, rsrc._ready_to_extend_volume())
+
+        self.patchobject(cinder.CinderClientPlugin, 'get_max_microversion',
+                         return_value='3.42')
+        self.assertEqual(False, rsrc._ready_to_extend_volume())
+        self.assertEqual(False, rsrc._ready_to_extend_volume())
+        self.assertEqual(False, rsrc._ready_to_extend_volume())
+        self.assertEqual(True, rsrc._ready_to_extend_volume())
+        self.assertEqual(True, rsrc._ready_to_extend_volume())
+
+    def test_try_detach_volume_if_server_was_temporarily_in_error(self):
+        self.stack_name = 'test_cvolume_detach_server_in_error_stack'
+        fva = vt_base.FakeVolume('in-use')
+        m_v = self._mock_create_server_volume_script(
+            vt_base.FakeVolume('attaching'))
+        self._mock_create_volume(vt_base.FakeVolume('creating'),
+                                 self.stack_name,
+                                 extra_get_mocks=[
+                                     m_v, fva,
+                                     vt_base.FakeVolume('available')])
+        self.stub_VolumeConstraint_validate()
+        # delete script
+        self.fc.volumes.get_server_volume.side_effect = [
+            fva, fva, fakes_nova.fake_exception()]
+        nova_responses = [nova_exp.Conflict('409'), None]
+        self.fc.volumes.delete_server_volume.side_effect = nova_responses
+        stack = utils.parse_stack(self.t, stack_name=self.stack_name)
+        self.create_volume(self.t, stack, 'volume')
+        rsrc = self.create_attachment(self.t, stack, 'attachment')
+        scheduler.TaskRunner(rsrc.delete)()
+        self.assertEqual(self.fc.volumes.delete_server_volume.call_count,
+                         len(nova_responses))
