@@ -46,13 +46,13 @@ class TestRequestContext(common.HeatTestCase):
                     'roles': ['arole', 'notadmin'],
                     'tenant_id': '456tenant',
                     'user_id': 'fooUser',
-                    'tenant': u'\u5218\u80dc',
+                    'tenant': '\u5218\u80dc',
                     'auth_url': 'http://xyz',
                     'aws_creds': 'blah',
                     'region_name': 'RegionOne',
                     'user_identity': 'fooUser 456tenant',
-                    'user_domain': None,
-                    'project_domain': None}
+                    'user_domain_id': None,
+                    'project_domain_id': None}
 
         super(TestRequestContext, self).setUp()
 
@@ -63,7 +63,7 @@ class TestRequestContext(common.HeatTestCase):
             password=self.ctx.get('password'),
             aws_creds=self.ctx.get('aws_creds'),
             project_name=self.ctx.get('tenant'),
-            tenant=self.ctx.get('tenant_id'),
+            project_id=self.ctx.get('tenant_id'),
             user=self.ctx.get('user_id'),
             auth_url=self.ctx.get('auth_url'),
             roles=self.ctx.get('roles'),
@@ -73,8 +73,8 @@ class TestRequestContext(common.HeatTestCase):
             trustor_user_id=self.ctx.get('trustor_user_id'),
             trust_id=self.ctx.get('trust_id'),
             region_name=self.ctx.get('region_name'),
-            user_domain_id=self.ctx.get('user_domain'),
-            project_domain_id=self.ctx.get('project_domain'))
+            user_domain_id=self.ctx.get('user_domain_id'),
+            project_domain_id=self.ctx.get('project_domain_id'))
         ctx_dict = ctx.to_dict()
         del ctx_dict['request_id']
         del ctx_dict['project_id']
@@ -96,15 +96,15 @@ class TestRequestContext(common.HeatTestCase):
                       'roles': ['arole', 'notadmin'],
                       'tenant_id': '456tenant',
                       'project_id': '456tenant',
-                      'user_id': u'Gāo',
-                      'tenant': u'\u5218\u80dc',
-                      'project_name': u'\u5218\u80dc',
+                      'user_id': 'Gāo',
+                      'tenant': '\u5218\u80dc',
+                      'project_name': '\u5218\u80dc',
                       'auth_url': 'http://xyz',
                       'aws_creds': 'blah',
                       'region_name': 'RegionOne',
-                      'user_identity': u'Gāo 456tenant',
-                      'user_domain': None,
-                      'project_domain': None}
+                      'user_identity': 'Gāo 456tenant',
+                      'user_domain_id': None,
+                      'project_domain_id': None}
 
         ctx = context.RequestContext(
             auth_token=ctx_origin.get('auth_token'),
@@ -112,7 +112,7 @@ class TestRequestContext(common.HeatTestCase):
             password=ctx_origin.get('password'),
             aws_creds=ctx_origin.get('aws_creds'),
             project_name=ctx_origin.get('tenant'),
-            tenant=ctx_origin.get('tenant_id'),
+            project_id=ctx_origin.get('tenant_id'),
             user=ctx_origin.get('user_id'),
             auth_url=ctx_origin.get('auth_url'),
             roles=ctx_origin.get('roles'),
@@ -122,10 +122,10 @@ class TestRequestContext(common.HeatTestCase):
             trustor_user_id=ctx_origin.get('trustor_user_id'),
             trust_id=ctx_origin.get('trust_id'),
             region_name=ctx_origin.get('region_name'),
-            user_domain_id=ctx_origin.get('user_domain'),
-            project_domain_id=ctx_origin.get('project_domain'))
+            user_domain_id=ctx_origin.get('user_domain_id'),
+            project_domain_id=ctx_origin.get('project_domain_id'))
         ctx_dict = ctx.to_dict()
-        del(ctx_dict['request_id'])
+        del ctx_dict['request_id']
         self.assertEqual(ctx_origin, ctx_dict)
 
     def test_request_context_from_dict(self):
@@ -146,7 +146,7 @@ class TestRequestContext(common.HeatTestCase):
                 continue
 
             # these values are different between attribute and context
-            if k == 'tenant' or k == 'user':
+            if k in ('tenant', 'user', 'tenant_id'):
                 continue
 
             self.assertEqual(self.ctx.get(k), ctx.to_dict().get(k))
@@ -391,7 +391,7 @@ class RequestContextMiddlewareTest(common.HeatTestCase):
     )]
 
     def setUp(self):
-        super(RequestContextMiddlewareTest, self).setUp()
+        super(RequestContextMiddlewareTest, self).setUp(mock_find_file=False)
         self.fixture = self.useFixture(config_fixture.Config())
         self.fixture.conf(args=['--config-dir', policy_path])
         policy_opts.set_defaults(cfg.CONF, 'check_admin.json')
