@@ -41,6 +41,11 @@ class TestFunction(function.Function):
         return 'wibble'
 
 
+class NullFunction(function.Function):
+    def result(self):
+        return Ellipsis
+
+
 class TestFunctionKeyError(function.Function):
     def result(self):
         raise TypeError
@@ -169,6 +174,28 @@ class ResolveTest(common.HeatTestCase):
                          result)
         self.assertIsNot(result, snippet)
 
+    def test_resolve_func_with_null(self):
+        func = NullFunction(None, 'foo', ['bar', 'baz'])
+
+        self.assertIsNone(function.resolve(func))
+        self.assertIs(Ellipsis, function.resolve(func, nullable=True))
+
+    def test_resolve_dict_with_null(self):
+        func = NullFunction(None, 'foo', ['bar', 'baz'])
+        snippet = {'foo': 'bar', 'baz': func, 'blarg': 'wibble'}
+
+        result = function.resolve(snippet)
+
+        self.assertEqual({'foo': 'bar', 'blarg': 'wibble'}, result)
+
+    def test_resolve_list_with_null(self):
+        func = NullFunction(None, 'foo', ['bar', 'baz'])
+        snippet = ['foo', func, 'bar']
+
+        result = function.resolve(snippet)
+
+        self.assertEqual(['foo', 'bar'], result)
+
 
 class ValidateTest(common.HeatTestCase):
     def setUp(self):
@@ -235,11 +262,11 @@ class ValidateGetAttTest(common.HeatTestCase):
         super(ValidateGetAttTest, self).setUp()
 
         env = environment.Environment()
-        env.load({u'resource_registry':
-                  {u'OS::Test::GenericResource': u'GenericResourceType'}})
+        env.load({'resource_registry':
+                  {'OS::Test::GenericResource': 'GenericResourceType'}})
 
-        env.load({u'resource_registry':
-                  {u'OS::Test::FakeResource': u'OverwrittenFnGetAttType'}})
+        env.load({'resource_registry':
+                  {'OS::Test::FakeResource': 'OverwrittenFnGetAttType'}})
 
         tmpl = template.Template({"HeatTemplateFormatVersion": "2012-12-12",
                                   "Resources": {
