@@ -92,7 +92,6 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
                              'No password configured')
         self.setup_clients(self.conf)
         self.useFixture(fixtures.FakeLogger(format=_LOG_FORMAT))
-        self.updated_time = {}
         if self.conf.disable_ssl_certificate_validation:
             self.verify_cert = False
         else:
@@ -101,10 +100,9 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
     def setup_clients(self, conf, admin_credentials=False):
         self.manager = clients.ClientManager(conf, admin_credentials)
         self.identity_client = self.manager.identity_client
+        self.keystone_client = self.manager.keystone_client
         self.orchestration_client = self.manager.orchestration_client
         self.compute_client = self.manager.compute_client
-        self.network_client = self.manager.network_client
-        self.volume_client = self.manager.volume_client
         self.object_client = self.manager.object_client
 
         self.client = self.orchestration_client
@@ -164,17 +162,15 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
             self.keypair = self.create_keypair()
             self.keypair_name = self.keypair.id
 
-    @classmethod
-    def _stack_rand_name(cls):
-        return rand_name(cls.__name__)
-
-    def _get_network(self, net_name=None):
-        if net_name is None:
-            net_name = self.conf.fixed_network_name
-        networks = self.network_client.list_networks()
-        for net in networks['networks']:
-            if net['name'] == net_name:
-                return net
+    def _stack_rand_name(self):
+        test_name = self.id()
+        if test_name and '.' in test_name:
+            name = '-'.join(test_name.split('.')[-2:])
+            # remove 'testname(...)' cases
+            name = name.split('(')[0]
+        else:
+            name = self.__name__
+        return rand_name(name)
 
     def is_service_available(self, service_type):
         try:
@@ -228,7 +224,7 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
         fail_regexp = re.compile(failure_pattern)
         build_timeout = self.conf.build_timeout
         build_interval = self.conf.build_interval
-
+        res = None
         start = timeutils.utcnow()
         while timeutils.delta_seconds(start,
                                       timeutils.utcnow()) < build_timeout:
@@ -254,9 +250,11 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
                         resource_status_reason=res.resource_status_reason)
             time.sleep(build_interval)
 
-        message = ('Resource %s failed to reach %s status within '
-                   'the required time (%s s).' %
-                   (resource_name, status, build_timeout))
+        message = ('Resource %s from stack %s failed to reach %s status '
+                   'within the required time (%s s). Current resource '
+                   'status: %s.' %
+                   (resource_name, stack_identifier, status, build_timeout,
+                    res.resource_status))
         raise exceptions.TimeoutException(message)
 
     def verify_resource_status(self, stack_identifier, resource_name,
@@ -270,17 +268,7 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
     def _verify_status(self, stack, stack_identifier, status,
                        fail_regexp, is_action_cancelled=False):
         if stack.stack_status == status:
-            # Handle UPDATE_COMPLETE/FAILED case: Make sure we don't
-            # wait for a stale UPDATE_COMPLETE/FAILED status.
-            if status in ('UPDATE_FAILED', 'UPDATE_COMPLETE'):
-                if is_action_cancelled:
-                    return True
-
-                if self.updated_time.get(
-                        stack_identifier) != stack.updated_time:
-                    self.updated_time[stack_identifier] = stack.updated_time
-                    return True
-            elif status == 'DELETE_COMPLETE' and stack.deletion_time is None:
+            if status == 'DELETE_COMPLETE' and stack.deletion_time is None:
                 # Wait for deleted_time to be filled, so that we have more
                 # confidence the operation is finished.
                 return False
@@ -290,20 +278,12 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
         wait_for_action = status.split('_')[0]
         if (stack.action == wait_for_action and
                 fail_regexp.search(stack.stack_status)):
-            # Handle UPDATE_COMPLETE/UPDATE_FAILED case.
-            if status in ('UPDATE_FAILED', 'UPDATE_COMPLETE'):
-                if self.updated_time.get(
-                        stack_identifier) != stack.updated_time:
-                    self.updated_time[stack_identifier] = stack.updated_time
-                    raise exceptions.StackBuildErrorException(
-                        stack_identifier=stack_identifier,
-                        stack_status=stack.stack_status,
-                        stack_status_reason=stack.stack_status_reason)
-            else:
-                raise exceptions.StackBuildErrorException(
-                    stack_identifier=stack_identifier,
-                    stack_status=stack.stack_status,
-                    stack_status_reason=stack.stack_status_reason)
+            raise exceptions.StackBuildErrorException(
+                stack_identifier=stack_identifier,
+                stack_status=stack.stack_status,
+                stack_status_reason=stack.stack_status_reason)
+
+        return False
 
     def _wait_for_stack_status(self, stack_identifier, status,
                                failure_pattern=None,
@@ -352,8 +332,9 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
             time.sleep(build_interval)
 
         message = ('Stack %s failed to reach %s status within '
-                   'the required time (%s s).' %
-                   (stack_identifier, status, build_timeout))
+                   'the required time (%s s). Current stack state: %s.' %
+                   (stack_identifier, status, build_timeout,
+                    stack.stack_status))
         raise exceptions.TimeoutException(message)
 
     def _stack_delete(self, stack_identifier):
@@ -393,9 +374,6 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
         env_files = files or {}
         parameters = parameters or {}
 
-        self.updated_time[stack_identifier] = self.client.stacks.get(
-            stack_identifier, resolve_outputs=False).updated_time
-
         self._handle_in_progress(
             self.client.stacks.update,
             stack_id=stack_identifier,
@@ -421,9 +399,6 @@ class HeatIntegrationTest(testscenarios.WithScenarios,
 
         stack_name = stack_identifier.split('/')[0]
 
-        self.updated_time[stack_identifier] = self.client.stacks.get(
-            stack_identifier, resolve_outputs=False).updated_time
-
         if rollback:
             self.client.actions.cancel_update(stack_name)
         else:
